@@ -1,5 +1,10 @@
 #include "common.h"
 
+const char * memcached_lib_version(void) 
+{
+  return LIBMEMCACHED_VERSION_STRING;
+}
+
 memcached_return memcached_version(memcached_st *ptr)
 {
   unsigned int x;
@@ -16,14 +21,14 @@ memcached_return memcached_version(memcached_st *ptr)
   {
     memcached_return rrc;
 
-    rrc= memcached_do(ptr, x, command, send_length, 1);
+    rrc= memcached_do(&ptr->hosts[x], command, send_length, 1);
     if (rrc != MEMCACHED_SUCCESS)
     {
       rc= MEMCACHED_SOME_ERRORS;
       continue;
     }
 
-    rrc= memcached_response(ptr, buffer, MEMCACHED_DEFAULT_COMMAND_SIZE, NULL, x);
+    rrc= memcached_response(&ptr->hosts[x], buffer, MEMCACHED_DEFAULT_COMMAND_SIZE, NULL);
     if (rrc != MEMCACHED_SUCCESS)
       rc= MEMCACHED_SOME_ERRORS;
 
